==> pencilbox-1.0.1-src.zip: src/pencilbox/tentaisho/Area.java <==
package pencilbox.tentaisho;

import java.util.Iterator;

import pencilbox.common.core.Address;


/**
 * uṼV[v̈NX
 */
public class Area extends pencilbox.common.core.Area {
	/**
	 * ̈Ɋ܂܂鐯̎
	 * Ȃ 0;   1;  2;  -1:
	 */
	private int starType;
	private StarAddress starPos;	// ̈Ɋ܂܂鐯̍W 1݂̂̂Ƃ݈̂Ӗ

	/**
	 * @return Returns the starColor.
	 */
	int getStarType() {
		return starType;
	}

	/**
	 * @param starColor The starColor to set.
	 */
	void setStarType(int starColor) {
		this.starType = starColor;
	}

	/**
	 * @return Returns the starPos.
	 */
	StarAddress getStarPos() {
		return starPos;
	}

	/**
	 * @param starPos The starPos to set.
	 */
	void setStarPos(StarAddress starPos) {
		this.starPos = starPos;
	}

	public String toString() {
		return ":" + starType + " W:" + starPos.toString() +"\n̈"+ super.toString();	
	}

	/**
	 * ̈悪ЂƂ̂݊܂݁C̒S_Ɉʒu鐯ɑ΂ē_Ώ̂ǂ𒲂ׂ
	 * @return _Ώ̂Ȃ <tt>true</tt>
	 */
	public boolean isPointSymmetry() {
		if (starPos.isNowhere()) return false;
		Address posa, posb;
		for (Iterator itr = iterator(); itr.hasNext(); ) {
			posa = (Address) itr.next();
			posb = getPointSymmericAddress(posa, starPos);
			if (!contains(posb)) { 
				return false;  
			}
		}
		return true;
	}
	/**
	 * ̈悪^ꂽS_ɑ΂ē_Ώ̂ǂ
	 */
//	private boolean isPointSymmetry(StarAddress center) {
//		Address posa, posb;
//		for (Iterator itr = iterator(); itr.hasNext(); ) {
//			posa = (Address) itr.next();
//			posb = getPointSymmericAddress(posa, center);
//			if (!contains(posb)) { 
//				return false;  
//			}
//		}
//		return true;
//	}
	/**
	 * position  center ɑ΂ē_Ώ̂ Address ߂
	 * @param position W
	 * @param center _Ώ̒SƂȂW
	 * @return cnterɑ΂positionƓ_Ώ̂ȍW
	 */
	public Address getPointSymmericAddress(Address position, StarAddress center) {
		return new Address(center.r-position.r, center.c-position.c);
	}

	/**
	 * 	̈̒S}XԂ
	 * @return ̈̒S}X
	 */
	public Address getCenterCell() {
		return new Address(starPos.r/2, starPos.c/2);
	}

}

/*
 * ̈̌`ɂꍇ킯
 *  ̐܂
 *  ЂƂ܂܂Ȃ
 *  ЂƂ܂
 * 		_Ώ̂
 * 		_Ώ̂łȂ
 */

==> pencilbox-1.2.0-src.zip: src/pencilbox/tentaisho/Area.java <==
package pencilbox.tentaisho;

import java.util.Iterator;

import pencilbox.common.core.Address;


/**
 * uṼV[v̈NX
 */
public class Area extends pencilbox.common.core.Area {
	/**
	 * ̈Ɋ܂܂鐯̎
	 * Ȃ 0;   1;  2;  -1:
	 */
	private int starType;
	private StarAddress starPos;	// ̈Ɋ܂܂鐯̍W 1݂̂̂Ƃ݈̂Ӗ

	/**
	 * @return Returns the starColor.
	 */
	int getStarType() {
		return starType;
	}

	/**
	 * @param starColor The starColor to set.
	 */
	void setStarType(int starColor) {
		this.starType = starColor;
	}

	/**
	 * @return Returns the starPos.
	 */
	StarAddress getStarPos() {
		return starPos;
	}

	/**
	 * @param starPos The starPos to set.
	 */
	void setStarPos(StarAddress starPos) {
		this.starPos = starPos;
	}

	public String toString() {
		return ":" + starType + " W:" + starPos.toString() +"\n̈"+ super.toString();	
	}

	/**
	 * ̈悪ЂƂ̂݊܂݁C̒S_Ɉʒu鐯ɑ΂ē_Ώ̂ǂ𒲂ׂ
	 * @return _Ώ̂Ȃ <tt>true</tt>
	 */
	public boolean isPointSymmetry() {
		if (starPos.isNowhere()) return false;
		Address posa, posb;
		for (Iterator itr = iterator(); itr.hasNext(); ) {
			posa = (Address) itr.next();
			posb = getPointSymmericAddress(posa, starPos);
			if (!contains(posb)) { 
				return false;  
			}
		}
		return true;
	}
	/**
	 * ̈悪^ꂽS_ɑ΂ē_Ώ̂ǂ
	 */
//	private boolean isPointSymmetry(StarAddress center) {
//		Address posa, posb;
//		for (Iterator itr = iterator(); itr.hasNext(); ) {
//			posa = (Address) itr.next();
//			posb = getPointSymmericAddress(posa, center);
//			if (!contains(posb)) { 
//				return false;  
//			}
//		}
//		return true;
//	}
	/**
	 * position  center ɑ΂ē_Ώ̂ Address ߂
	 * @param position W
	 * @param center _Ώ̒SƂȂW
	 * @return cnterɑ΂positionƓ_Ώ̂ȍW
	 */
	public Address getPointSymmericAddress(Address position, StarAddress center) {
		return new Address(center.r()-position.r(), center.c()-position.c());
	}

	/**
	 * 	̈̒S}XԂ
	 * @return ̈̒S}X
	 */
	public Address getCenterCell() {
		return new Address(starPos.r()/2, starPos.c()/2);
	}

}

/*
 * ̈̌`ɂꍇ킯
 *  ̐܂
 *  ЂƂ܂܂Ȃ
 *  ЂƂ܂
 * 		_Ώ̂
 * 		_Ώ̂łȂ
 */
